﻿Write-Progress -Activity "Collecting diagnostics information for .NET Core agent" -Status "Please wait"  

try
{
$w3svc = Get-ItemProperty -Path HKLM:\SYSTEM\CurrentControlSet\Services\W3SVC 
$was = Get-ItemProperty -Path HKLM:\SYSTEM\CurrentControlSet\Services\WAS 
$OFS = "`r`n"

$parentPath = Split-Path $PSScriptRoot -Parent
$versionPath = (Join-Path $parentPath "version.info")	

$AgentDiagnosticsPath = ".\AgentDiagnostics"

if (Test-Path $AgentDiagnosticsPath) { Remove-Item $AgentDiagnosticsPath -Recurse; }

$result = New-Item -ItemType directory -Path $AgentDiagnosticsPath
$path = (Resolve-Path -Path $AgentDiagnosticsPath).Path
$applicationEventLog = "$path\Application.evtx"
$systemInfofile = "$AgentDiagnosticsPath\system.info"
$diagnosticFile = ".\AgentDiagnostics.zip"
#-------------------------------------------------------------------------------------



systeminfo | Out-File -FilePath $systemInfofile -NoClobber

Add-Content $systemInfofile "$OFS--------------HKLM:\SYSTEM\ControlSet001\Services\W3SVC:Environment----------"
$w3svc.Environment | Out-File -FilePath $systemInfofile -NoClobber -Append

Add-Content $systemInfofile "$OFS--------------HKLM:\SYSTEM\ControlSet001\Services\WAS:Environment----------"
$was.Environment | Out-File -FilePath $systemInfofile -NoClobber -Append


Add-Content $systemInfofile "$OFS--------------Global:Environment----------"
echo "CORECLR_ENABLE_PROFILING=$env:CORECLR_ENABLE_PROFILING" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "CORECLR_PROFILER=$env:CORECLR_PROFILER" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "CORECLR_PROFILER_PATH_64=$env:CORECLR_PROFILER_PATH_64" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "CORECLR_PROFILER_PATH_32=$env:CORECLR_PROFILER_PATH_32" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "CORECLR_SITE24X7_HOME=$env:CORECLR_SITE24X7_HOME" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "DOTNET_ADDITIONAL_DEPS=$env:DOTNET_ADDITIONAL_DEPS" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "DOTNET_SHARED_STORE=$env:DOTNET_SHARED_STORE" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "S247_LICENSE_KEY=$env:S247_LICENSE_KEY" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "COR_ENABLE_PROFILING=$env:COR_ENABLE_PROFILING" | Out-File -FilePath $systemInfofile -NoClobber -Append
echo "COR_PROFILER=$env:COR_PROFILER" | Out-File -FilePath $systemInfofile -NoClobber -Append

Add-Content $systemInfofile "$OFS--------------.NET Core info----------"
dotnet --info | Out-File -FilePath $systemInfofile -NoClobber -Append

#Reading .NET Core process with environment variables--------------------------
Add-Content $systemInfofile "$OFS***************************.NET Core processes***********************************"
$currentPath = (Get-Location).Path
$Assembly = [System.Reflection.Assembly]::LoadFrom("$currentPath\ProcessUtil.dll");

$processes = get-process | where {$_.ProcessName -eq "w3wp"}
foreach ($process in $processes)
{ 
    Add-Content $systemInfofile "$OFS--------------Process Id : $($process.Id) -------------------"
    Get-Process -Id $process.Id | Out-File -FilePath $systemInfofile -NoClobber -Append -Width 100
    [ProcessUtil.Util.ProcessExtensions]::GetEnvironmentVariables($process.Id) | Out-File -FilePath $systemInfofile -NoClobber -Append
    Add-Content $systemInfofile "$OFS---------------------------------------------------"
}

$processes = get-process | where {$_.ProcessName -eq "dotnet"}
foreach ($process in $processes) 
{  
    Add-Content $systemInfofile "$OFS--------------Process Id : $($process.Id) -------------------"
    Get-Process -Id $process.Id | Out-File -FilePath $systemInfofile -NoClobber -Append -Width 100
    [ProcessUtil.Util.ProcessExtensions]::GetEnvironmentVariables($process.Id) | Out-File -FilePath $systemInfofile -NoClobber -Append
    Add-Content $systemInfofile "$OFS---------------------------------------------------"
}
#-------------------------------------------------------------------------
Add-Content $systemInfofile "$OFS*********************************************************************************************"
#Exporting eventlog
$eventLog = (Get-WmiObject -Class Win32_NTEventlogFile | Where-Object LogfileName -EQ 'Application').BackupEventlog($applicationEventLog)

#Copying the agent log files
Copy-Item (Join-Path $parentPath "DotNetAgent") -destination $AgentDiagnosticsPath -recurse -for
Copy-Item $versionPath -destination $AgentDiagnosticsPath -recurse -for


$compress = @{
LiteralPath= $AgentDiagnosticsPath
CompressionLevel = "Fastest"
DestinationPath = $diagnosticFile
}
Compress-Archive @compress -Force

Remove-Item $AgentDiagnosticsPath -Recurse

Write-Host "Diagnostics zip file is generated." 
Write-Host "Send the file AgentDiagnostics.zip to appmanager-support@manageengine.com for analysis." 
}
catch
{
    "An error occurred:"
    Write-Error $_
    Add-Content $systemInfofile "$OFS-------------Error in Agent Diagnostics script.---------------"
    Add-Content $systemInfofile $_
    Write-Host "If you find the AgentDiagnostics folder with the some log files, kindly zip the folder and send it to support@site24x7.com for analysis."
}

